@@ -1,7 +1,7 @@
 /* rzxdump.c: get info on an RZX file
    Copyright (c) 2002-2003 Philip Kendall
 
-   $Id: rzxdump.c 3432 2007-12-18 23:47:53Z zubzero $
+   $Id: rzxdump.c 4767 2012-11-18 18:49:54Z sbaldovi $
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -34,9 +34,9 @@
 #include <unistd.h>
 #include <errno.h>
 
-#ifdef HAVE_LIBGCRYPT
+#ifdef HAVE_GCRYPT_H
 #include <gcrypt.h>
-#endif				/* #ifdef HAVE_LIBGCRYPT */
+#endif				/* #ifdef HAVE_GCRYPT_H */
 
 #include <libspectrum.h>
 
@@ -319,10 +319,10 @@ static int
 read_sign_end_block( unsigned char **ptr, unsigned char *end )
 {
   size_t length;
-#ifdef HAVE_LIBGCRYPT
+#ifdef HAVE_GCRYPT_H
   gcry_mpi_t a; int error; size_t length2;
   unsigned char *buffer;
-#endif				/* #ifdef HAVE_LIBGCRYPT */
+#endif				/* #ifdef HAVE_GCRYPT_H */
 
   if( end - *ptr < 4 ) {
     fprintf( stderr, "%s: not enough bytes for sign end block\n", progname );
@@ -341,7 +341,7 @@ read_sign_end_block( unsigned char **ptr, unsigned char *end )
     return 1;
   }
 
-#ifdef HAVE_LIBGCRYPT
+#ifdef HAVE_GCRYPT_H
 
   error = gcry_mpi_scan( &a, GCRYMPI_FMT_PGP, *ptr, length, &length2 );
   if( error ) {
@@ -367,7 +367,7 @@ read_sign_end_block( unsigned char **ptr, unsigned char *end )
   printf( "  s: %s\n", buffer );
   free( buffer ); gcry_mpi_release( a );
 
-#endif
+#endif				/* #ifdef HAVE_GCRYPT_H */
 
   (*ptr) += length;
 
