@@ -4,7 +4,7 @@
 		 2003 Tomaz Kac,
 		 2003 Philip Kendall
 
-   $Id: snap2tzx.c 4062 2009-08-02 14:22:04Z fredm $
+   $Id: snap2tzx.c 4754 2012-10-26 13:07:27Z fredm $
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -61,8 +61,14 @@ static libspectrum_byte WorkBuffer[65535];
 
 static int verbose = 0;
 
+static void print_error( const char *format, ... )
+     GCC_PRINTF( 1, 2 );
+
+static void print_verbose( const char *format, ... )
+     GCC_PRINTF( 1, 2 );
+
 static void
-print_error( char *format, ... )
+print_error( const char *format, ... )
 {
   va_list ap;
 
@@ -76,7 +82,7 @@ print_error( char *format, ... )
 }
 
 static void
-print_verbose( char *format, ... )
+print_verbose( const char *format, ... )
 {
   va_list ap;
 
@@ -101,10 +107,10 @@ static void crunch_z80 (libspectrum_byte *BufferIn, libspectrum_word BlLength, l
 /**********************************************************************************************************************************/
 
 {
-  libspectrum_word register IndexIn;
-  libspectrum_word register IndexOut       = 0;
+  register libspectrum_word IndexIn;
+  register libspectrum_word IndexOut       = 0;
   libspectrum_word          LengthOut;
-  libspectrum_word register RunTimeLength;
+  register libspectrum_word RunTimeLength;
   int          CrunchIt       = 0;
   libspectrum_byte          RepeatedCode;
   libspectrum_byte          PrevByte       = 0x00;
@@ -169,7 +175,6 @@ int test_decz80(libspectrum_byte *source, int final_len, int source_len)
 	libspectrum_byte b1;
 	libspectrum_byte b2;
 	libspectrum_byte times;
-	libspectrum_byte value;
 
 	int off = src_pnt;
 
@@ -183,7 +188,6 @@ int test_decz80(libspectrum_byte *source, int final_len, int source_len)
 		{
 		  /* Repeat */
 			times = source[(src_pnt-off)+1];
-			value = source[(src_pnt-off)+2];
 			dst_pnt += times;
 			src_pnt+=3;
 		}
@@ -213,7 +217,6 @@ test_rev_decz80( libspectrum_byte *source, int final_len, int source_len )
 	libspectrum_byte b1;
 	libspectrum_byte b2;
 	libspectrum_byte times;
-	libspectrum_byte value;
 
 	while (dst_pnt >=0 && !overwrite)
 	{
@@ -225,7 +228,6 @@ test_rev_decz80( libspectrum_byte *source, int final_len, int source_len )
 		{
 		  /* Repeat */
 			times = source[src_pnt-1];
-			value = source[src_pnt-2];
 			dst_pnt -= times;
 			src_pnt-=3;
 		}
@@ -244,7 +246,7 @@ test_rev_decz80( libspectrum_byte *source, int final_len, int source_len )
 
 static void reverse_block (libspectrum_byte *BufferOut, libspectrum_byte *BufferIn)
 {
-  libspectrum_word register  Cnt;
+  register libspectrum_word Cnt;
   libspectrum_byte          *BIn;
   libspectrum_byte          *BOut;
 
@@ -856,7 +858,7 @@ static const libspectrum_byte loader_data[ 0x300 ] =
 static libspectrum_byte
 calc_checksum( libspectrum_byte *data, size_t length )
 {
-  int i;
+  size_t i;
   libspectrum_byte checksum;
 
   for( i=0, checksum = 0; i < length; i++, data++ ) checksum ^= *data;
@@ -1157,7 +1159,7 @@ get_loading_screen( libspectrum_byte *screen, const char *filename )
 
   count = fread( screen, 1, 6912, f );
   if( count != 6912 ) {
-    if( count == -1 ) {
+    if( count == 0 ) {
       print_error( "error reading from '%s: %s", filename, strerror( errno ) );
     } else {
       print_error( "could read only %lu bytes from '%s'", (unsigned long)count,
@@ -1211,13 +1213,13 @@ add_page( libspectrum_tape *tape, libspectrum_snap *snap, int page,
     /* compressed_length == 0 => block could not be compressed */
     if( !compressed_length ) {
       print_verbose(
-        "- adding separate loading screen (uncompressed) length: %04x\n",
-	page_length
+        "- adding separate loading screen (uncompressed) length: %04lx\n",
+	(unsigned long)page_length
       );
     } else {
       print_verbose(
-        "- adding separate loading screen   (compressed) length: %04x\n",
-	compressed_length
+        "- adding separate loading screen   (compressed) length: %04lx\n",
+	(unsigned long)compressed_length
       );
     }
 
@@ -1283,13 +1285,13 @@ add_page( libspectrum_tape *tape, libspectrum_snap *snap, int page,
 
     if( compressed_length == 0 ) {
       print_verbose(
-        "- adding memory page %d           (uncompressed) length: %04x\n",
-	page, page_length
+        "- adding memory page %d           (uncompressed) length: %04lx\n",
+	page, (unsigned long)page_length
       );
     } else {
       print_verbose(
-	"- adding memory page %d             (compressed) length: %04x\n",
-	page, compressed_length
+	"- adding memory page %d             (compressed) length: %04lx\n",
+	page, (unsigned long)compressed_length
       );
     }
 
@@ -1456,7 +1458,7 @@ write_tape( libspectrum_tape *tape, const char *filename )
 
   written = fwrite( buffer, 1, length, f );
   if( written != length ) {
-    if( written == -1 ) {
+    if( written == 0 ) {
       print_error( "error writing to '%s': %s", filename, strerror( errno ) );
     } else {
       print_error( "could write only %lu of %lu bytes to '%s'",
